@@ -85,9 +85,9 @@
 #' Because of Flash security settings the chart might not work correctly when
 #' accessed from a file location in the browser (e.g.,
 #' file:///c:/webhost/myhost/myviz.html) rather than from a web server URL
-#' (e.g. http://www.myhost.com/myviz.html). See the googleVis package vignette
+#' (e.g. https://www.myhost.com/myviz.html). See the googleVis package vignette
 #' and the Macromedia web site
-#' (\url{http://www.macromedia.com/support/documentation/en/flashplayer/help/})
+#' (\url{https://www.macromedia.com/support/documentation/en/flashplayer/help/})
 #' for more details.
 #' 
 #' Important: To use this visualization, you must specify the height and width 
@@ -169,63 +169,13 @@
 #' plot(A5)
 #' 
 #' 
-#' \dontrun{
-#' 
-#' ## Plot Apple's monthly stock prices since 1984
-#' 
-#' ## Get current date
-#' d <- Sys.time() 
-#' current.year <- format(d, "%Y")
-#' current.month <- format(d, "%m")
-#' current.day <- format(d, "%d")
-#' 
-#' ## Yahoo finance sets January to 00 hence: 
-#' month <- as.numeric(current.month)  - 1
-#' month <- ifelse(month < 10, paste("0",month, sep=""), m)
-#' 
-#' ## Get weekly stock prices from Apple Inc.
-#' tckr <- 'AAPL'
-#' yahoo <- 'http://ichart.finance.yahoo.com/table.csv'
-#' 
-#' fn <- sprintf('%s?s=%s&a=08&b=7&c=1984&d=%s&e=%s&f=%s&g=w&ignore=.csv',
-#'       yahoo, tckr, month, current.day, current.year)
-#' 
-#' ## Get data from Yahoo! Finance
-#' data <- read.csv(fn, colClasses=c("Date", rep("numeric",6)))
-#' 
-#' AAPL <- reshape(data[,c("Date", "Close", "Volume")], idvar="Date", 
-#'      		times=c("Close", "Volume"), 
-#'                 timevar="Type",
-#'                 varying=list(c("Close", "Volume")),
-#'                 v.names="Value",
-#'                 direction="long")
-#' 
-#' ## Calculate previous two years for zoom start time
-#' lyd <- as.POSIXlt(as.Date(d))
-#' lyd$year <- lyd$year-2
-#' lyd <- as.Date(lyd)
-#' 
-#' aapl <- gvisAnnotatedTimeLine(AAPL, datevar="Date",
-#'                            numvar="Value", idvar="Type",
-#'                           options=list(
-#'                             colors="['blue', 'lightblue']",
-#'                             zoomStartTime=lyd,
-#'                             zoomEndTime=as.Date(d),
-#'                             legendPosition='newRow',
-#'                             width="600px", height="400px", scaleColumns='[0,1]',
-#'                             scaleType='allmaximized')
-#'                            )
-#' 
-#' plot(aapl)
-#' }
 #' 
 gvisAnnotatedTimeLine <- function(data, datevar="", 
                                   numvar="", idvar="", titlevar="", 
                                   annotationvar="", 
                                   date.format="%Y/%m/%d",
                                   options=list(), chartid){
-  warning("AnnotatedTimeline (gvisAnnotatedTimeLine) is Flash based, conisder using  AnnotationChart (gvisAnnotationChart) instead.\nFor more details visit: goo.gl/tkiEV8")
-  
+  warning("AnnotatedTimeline (gvisAnnotatedTimeLine) is Flash based, consider using  AnnotationChart (gvisAnnotationChart) instead.")
   
   my.type <- "AnnotatedTimeLine"
   dataName <- deparse(substitute(data))
