@@ -9,6 +9,7 @@ shinyServer(function(input, output) {
   })
   
   output$view <- renderGvis({
-    gvisScatterChart(datasetInput())
+    gvisScatterChart(datasetInput(), 
+                     options=list(title=paste('Data:',input$dataset)))
   })
 })
\ No newline at end of file
